@@ -37,6 +37,7 @@ from switchbot_api.commands import (
     RGBWLightCommands,
     RGBWWLightCommands,
     RollerShadeCommands,
+    SmartRadiatorThermostatCommands,
     SpeakerCommands,
     Switch2PMCommands,
     SwitchCommands,
@@ -54,6 +55,7 @@ from switchbot_api.exceptions import (
 from switchbot_api.models import (
     BatteryCirculatorFanMode,
     PowerState,
+    SmartRadiatorThermostatMode,
     VacuumCleanMode,
     VacuumFanSpeed,
     VacuumFanSpeedV2,
@@ -71,6 +73,7 @@ __all__ = [
     "CommonCommands",
     "CurtainCommands",
     "DVDCommands",
+    "Device",
     "DoorBellCommands",
     "FanCommands",
     "HumidifierCommands",
@@ -82,9 +85,13 @@ __all__ = [
     "PowerState",
     "RGBWLightCommands",
     "RGBWWLightCommands",
+    "Remote",
     "RollerShadeCommands",
+    "SmartRadiatorThermostatCommands",
+    "SmartRadiatorThermostatMode",
     "SpeakerCommands",
     "Switch2PMCommands",
+    "SwitchBotAPI",
     "SwitchCommands",
     "T",
     "TVCommands",
